@@ -1,16 +1,24 @@
-/* $Id: cdb.c,v 1.16 2006/06/28 15:01:54 mjt Exp $
+/* $Id: cdb.c,v 1.18 2008-11-06 22:37:33 mjt Exp $
  * cdb command line tool
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
  * Public domain.
  */
 
-#define _GNU_SOURCE
+#define _GNU_SOURCE	/* #define this even on Windows */
+
+#ifdef _WIN32		/* by the way, how about win64? */
+# include <io.h>
+# include <malloc.h>
+# pragma warning(disable: 4996)
+#else
+# include <unistd.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stdarg.h>
-#include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
 #include "cdb.h"
@@ -33,6 +41,12 @@ static char *progname;
 # define O_NOFOLLOW 0
 #endif
 
+#ifdef _WIN32
+# define FBINMODE "b"
+#else
+# define FBINMODE
+#endif
+
 #define F_DUPMASK	0x000f
 #define F_WARNDUP	0x0100
 #define F_ERRDUP	0x0200
@@ -160,7 +174,7 @@ dmode(char *dbname, char mode, int flags)
   FILE *f;
   if (strcmp(dbname, "-") == 0)
     f = stdin;
-  else if ((f = fopen(dbname, "r")) == NULL)
+  else if ((f = fopen(dbname, "r" FBINMODE)) == NULL)
     error(errno, "open %s", dbname);
   allocbuf(2048);
   fget(f, buf, 2048, &pos, 2048);
@@ -202,7 +216,7 @@ static int smode(char *dbname) {
 
   if (strcmp(dbname, "-") == 0)
     f = stdin;
-  else if ((f = fopen(dbname, "r")) == NULL)
+  else if ((f = fopen(dbname, "r" FBINMODE)) == NULL)
     error(errno, "open %s", dbname);
 
   pos = 0;
