@@ -1,4 +1,4 @@
-/* $Id: nss_cdb.c,v 1.4 2003/11/30 19:43:16 mjt Exp $
+/* $Id: nss_cdb.c,v 1.5 2006-06-28 17:49:21 mjt Exp $
  * nss_cdb common routines.
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -6,6 +6,7 @@
  */
 
 #include "nss_cdb.h"
+#include "cdb_int.h"	/* for internal_function */
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -66,7 +67,7 @@ __nss_cdb_doendent(struct nss_cdb *dbp) {
   dbp->keepopen = 0;
 }
 
-enum nss_status
+enum nss_status internal_function
 __nss_cdb_setent(struct nss_cdb *dbp, int stayopen) {
   enum nss_status r;
   lock_lock(lock);
@@ -78,7 +79,7 @@ __nss_cdb_setent(struct nss_cdb *dbp, int stayopen) {
   return r;
 }
 
-enum nss_status
+enum nss_status internal_function
 __nss_cdb_endent(struct nss_cdb *dbp) {
   lock_lock(lock);
   if (isopen(dbp))
@@ -110,7 +111,7 @@ __nss_cdb_dobyname(struct nss_cdb *dbp, const char *key, unsigned len,
   return NSS_STATUS_SUCCESS;
 }
 
-enum nss_status
+enum nss_status internal_function
 __nss_cdb_byname(struct nss_cdb *dbp, const char *name,
                  void *result, char *buf, size_t bufl, int *errnop) {
   enum nss_status r;
@@ -146,7 +147,7 @@ __nss_cdb_dobyid(struct nss_cdb *dbp, unsigned long id,
   return __nss_cdb_dobyname(dbp, data, len, result, buf, bufl, errnop);
 }
 
-enum nss_status
+enum nss_status internal_function
 __nss_cdb_byid(struct nss_cdb *dbp, unsigned long id,
                void *result, char *buf, size_t bufl, int *errnop) {
   enum nss_status r;
@@ -193,7 +194,7 @@ __nss_cdb_dogetent(struct nss_cdb *dbp,
     return *errnop = ENOENT, NSS_STATUS_NOTFOUND;
 }
 
-enum nss_status
+enum nss_status internal_function
 __nss_cdb_getent(struct nss_cdb *dbp,
                  void *result, char *buf, size_t bufl, int *errnop) {
   enum nss_status r;
